### pymdgen.test_module

A module to use as a target during unit tests

### Functions
---

#### decorated_func
`def decorated_func(*args)`

this is a decorated function

---
#### dummy_func
`def dummy_func()`

this is a dummy func

---
### Classes
---

#### dummy

```
dummy(__builtin__.object)
```

this is a dummy class


more class docstr


##### Class Attributes

- test_property (`prop Instance`): property help

##### Instanced Attributes

These attributes / properties will be available on instances of the class

- another arbitrary property
- arbitrary property
- dummy_property (`@property`): this is a dummy property

##### Class Methods

###### dummy_classmethod
`def dummy_classmethod(self)`

this is a dummy classmethod

---

##### Methods

###### dummy_method
`def dummy_method(self)`

this is a dummy func

---
